class Array
	def count()
		if defined? nitems
			return nitems
		else
			return super
		end
	end
	def find_index(idx)
		index(idx)
	end
end

class Dir
	def exists?(path)
		File.directory?(path)
	end
end

def Process::spawn(command, *)
	pid = fork do
		FileUtils.chdir(ENV['HOME'])
		STDOUT.reopen('/dev/null')
		STDIN.reopen('/dev/null')
		Process.setpgid(0, 0)
		exec command
	end
	pid
end
